@@ -20,6 +20,7 @@
 #define NCNN_SIMPLEOCV 0
 #define NCNN_SIMPLEOMP 0
 #define NCNN_SIMPLESTL 0
+#define NCNN_SIMPLEMATH 0
 #define NCNN_THREADS 1
 #define NCNN_BENCHMARK 0
 #define NCNN_C_API 1
@@ -29,6 +30,7 @@
 #define NCNN_PIXEL_AFFINE 1
 #define NCNN_PIXEL_DRAWING 1
 #define NCNN_VULKAN 1
+#define NCNN_SIMPLEVK 1
 #define NCNN_SYSTEM_GLSLANG 1
 #define NCNN_RUNTIME_CPU 1
 #define NCNN_GNU_INLINE_ASM 1
@@ -61,7 +63,7 @@
 #define NCNN_BF16 1
 #define NCNN_FORCE_INLINE 1
 
-#define NCNN_VERSION_STRING "1.0.20230829"
+#define NCNN_VERSION_STRING "1.0.20240805"
 
 #include "ncnn_export.h"
 
@@ -234,6 +236,28 @@ private:
     Mutex& mutex;
 };
 
+static inline void swap_endianness_16(void* x)
+{
+    unsigned char* xx = (unsigned char*)x;
+    unsigned char x0 = xx[0];
+    unsigned char x1 = xx[1];
+    xx[0] = x1;
+    xx[1] = x0;
+}
+
+static inline void swap_endianness_32(void* x)
+{
+    unsigned char* xx = (unsigned char*)x;
+    unsigned char x0 = xx[0];
+    unsigned char x1 = xx[1];
+    unsigned char x2 = xx[2];
+    unsigned char x3 = xx[3];
+    xx[0] = x3;
+    xx[1] = x2;
+    xx[2] = x1;
+    xx[3] = x0;
+}
+
 } // namespace ncnn
 
 #if NCNN_SIMPLESTL
@@ -245,6 +269,23 @@ private:
 #include <string>
 #endif
 
+// simplemath
+#if NCNN_SIMPLEMATH
+#include "simplemath.h"
+#else
+#include <math.h>
+#include <fenv.h>
+#endif
+
+#if NCNN_VULKAN
+#if NCNN_SIMPLEVK
+#include "simplevk.h"
+#else
+#include <vulkan/vulkan.h>
+#endif
+#include "vulkan_header_fix.h"
+#endif // NCNN_VULKAN
+
 #endif // __cplusplus
 
 #if NCNN_STDIO
